@@ -1,6 +1,6 @@
-from scripts.deduplicate_music import deduplicate_music
+from scripts.bigdirs import bigdirs
+from scripts.dedupe import deduplicate_music
 from scripts.invalid_paths import rename_invalid_paths
-from scripts.large_folders import large_folders
 from scripts.merge_dbs import merge_dbs
 from scripts.merge_online_local import merge_online_local
 from scripts.mining.nfb_ca import nfb_films
